<?php
/**
 * Plugin Name: Export Category Name and Post ID's for eZbloo
 * Plugin URI:  https://ezbloo..com/
 * Description: Export all categories with associated post IDs as a CSV file for eZbloo
 * Version:     1.0
 * Author:      Maximus McCullough
 * Author URI:  https://a1websitepro.com
 * License:     GPL2
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Add admin menu
add_action('admin_menu', 'ecp_add_admin_menu');

function ecp_add_admin_menu() {
    add_menu_page(
        'Export Categories & Posts',
        'Export Categories',
        'manage_options',
        'export-categories-posts',
        'ecp_export_page',
        'dashicons-download',
        20
    );
}

// Admin page content
function ecp_export_page() {
    ?>
    <div class="wrap">
        <h1>Export Categories with Post id's for eZbloo</h1>
        <p>Click the button below to download a CSV file of all categories with their associated post IDs. You will then upload this file into your eZbloo system for your categories.</p>
        <form method="post" action="<?php echo admin_url('admin-post.php'); ?>">
            <input type="hidden" name="action" value="ecp_download_csv">
            <input type="submit" class="button button-primary" value="Download CSV">
        </form>
    </div>
    <?php
}

// Hook CSV generation to `admin_post` to avoid premature output
add_action('admin_post_ecp_download_csv', 'ecp_generate_csv');

function ecp_generate_csv() {
    global $wpdb;

    // Ensure no prior output
    if (ob_get_length()) {
        ob_clean();
    }

    header('Content-Type: text/csv; charset=utf-8');
    header('Content-Disposition: attachment; filename=categories_posts.csv');
    header('Pragma: no-cache');
    header('Expires: 0');

    $output = fopen('php://output', 'w');
    fputcsv($output, ['Category ID', 'Category Name', 'Post ID']);

    // Get all categories
    $categories = get_terms(['taxonomy' => 'category', 'hide_empty' => false]);

    if (!empty($categories)) {
        foreach ($categories as $category) {
            $category_id = $category->term_id;
            $category_name = $category->name;

            // Get post IDs associated with the category
            $post_ids = get_posts([
                'category' => $category_id,
                'fields' => 'ids',
                'posts_per_page' => -1
            ]);

            if (!empty($post_ids)) {
                foreach ($post_ids as $post_id) {
                    fputcsv($output, [$category_name, $post_id]);
                }
            } else {
                fputcsv($output, [$category_name, 'No Posts']);
            }
        }
    }

    fclose($output);
    exit;
}
